completion

package
v0.18.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 21, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CompleteDbBackupID added in v0.15.0

func CompleteDbBackupID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteDbBackupID provides completion for DBaaS backup IDs

func CompleteDbClusterID added in v0.12.0

func CompleteDbClusterID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

func CompleteDbEngineVersion added in v0.14.0

func CompleteDbEngineVersion(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteDbEngineVersion provides completion for DBaaS engine versions It requires the --engine flag to be set to determine which engine versions to return

func CompleteDbInstanceType added in v0.14.0

func CompleteDbInstanceType(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteDbInstanceType provides completion for DBaaS instance types

func CompleteIAMAppUserSubject added in v0.17.0

func CompleteIAMAppUserSubject(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMAppUserSubject completes user subjects from organisation members (for --user / --user-identity).

func CompleteIAMFederatedIdentityIdentity added in v0.17.0

func CompleteIAMFederatedIdentityIdentity(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMFederatedIdentityIdentity completes federated identity identifiers (first positional only).

func CompleteIAMFederatedIdentityIdentityFlag added in v0.17.0

func CompleteIAMFederatedIdentityIdentityFlag(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMFederatedIdentityIdentityFlag completes federated identities for flag values.

func CompleteIAMFederatedIdentityProviderIdentity added in v0.17.0

func CompleteIAMFederatedIdentityProviderIdentity(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMFederatedIdentityProviderIdentity completes federated identity provider identifiers (first positional only).

func CompleteIAMFederatedIdentityProviderIdentityFlag added in v0.17.0

func CompleteIAMFederatedIdentityProviderIdentityFlag(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMFederatedIdentityProviderIdentityFlag completes federated identity providers for flag values.

func CompleteIAMOrganisationMemberIdentity added in v0.17.0

func CompleteIAMOrganisationMemberIdentity(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMOrganisationMemberIdentity completes organisation member record identities.

func CompleteIAMOrganisationMemberType added in v0.17.0

func CompleteIAMOrganisationMemberType(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMOrganisationMemberType completes OWNER / MEMBER.

func CompleteIAMOrganisationRoleIdentity added in v0.17.0

func CompleteIAMOrganisationRoleIdentity(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMOrganisationRoleIdentity completes organisation role identities and slugs (first positional only).

func CompleteIAMOrganisationRoleIdentityFlag added in v0.17.0

func CompleteIAMOrganisationRoleIdentityFlag(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMOrganisationRoleIdentityFlag completes organisation roles for flag values (ignores positional args).

func CompleteIAMPermissionType added in v0.17.0

func CompleteIAMPermissionType(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMPermissionType completes permission values for role rules.

func CompleteIAMRoleThenBinding added in v0.17.0

func CompleteIAMRoleThenBinding(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMRoleThenBinding completes the role then binding identities for that role.

func CompleteIAMRoleThenRule added in v0.17.0

func CompleteIAMRoleThenRule(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMRoleThenRule completes the role then rule identities on that role.

func CompleteIAMServiceAccountIdentity added in v0.17.0

func CompleteIAMServiceAccountIdentity(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMServiceAccountIdentity completes service account identities (first positional only).

func CompleteIAMServiceAccountIdentityFlag added in v0.17.0

func CompleteIAMServiceAccountIdentityFlag(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMServiceAccountIdentityFlag completes service accounts for flag values (ignores positional args).

func CompleteIAMTeamIdentity added in v0.17.0

func CompleteIAMTeamIdentity(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMTeamIdentity completes team identities, slugs, and names (first positional only).

func CompleteIAMTeamIdentityFlag added in v0.17.0

func CompleteIAMTeamIdentityFlag(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMTeamIdentityFlag completes team identities for flag values (ignores positional args).

func CompleteIAMTeamThenTeamMember added in v0.17.0

func CompleteIAMTeamThenTeamMember(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMTeamThenTeamMember completes the team then team-member identities for that team.

func CompleteIAMWIFGitHubRefKind added in v0.17.0

func CompleteIAMWIFGitHubRefKind(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMWIFGitHubRefKind completes --ref-kind for GitHub bootstrap.

func CompleteIAMWIFGitLabRefType added in v0.17.0

func CompleteIAMWIFGitLabRefType(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteIAMWIFGitLabRefType completes common --ref-type values for GitLab bootstrap.

func CompleteKubernetesCluster added in v0.11.0

func CompleteKubernetesCluster(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteKubernetesCluster provides completion for Kubernetes cluster identities, names, and slugs

func CompleteKubernetesNodePool added in v0.14.0

func CompleteKubernetesNodePool(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteKubernetesNodePool provides completion for Kubernetes node pools It requires the --cluster flag to be set to determine which node pools to return

func CompleteKubernetesVersion added in v0.11.0

func CompleteKubernetesVersion(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteKubernetesVersion provides completion for Kubernetes versions

func CompleteMachineID

func CompleteMachineID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteMachineID provides completion for machine IDs

func CompleteMachineType added in v0.11.0

func CompleteMachineType(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteMachineType provides completion for machine types with descriptions

func CompleteNatGatewayID

func CompleteNatGatewayID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteNatGatewayID provides completion for NAT gateway IDs

func CompleteOrganisation added in v0.13.0

func CompleteOrganisation(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteOrganisation provides completion for organisation identities and slugs

func CompleteOutputFormat

func CompleteOutputFormat(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteOutputFormat provides completion for output format options

func CompleteRegion

func CompleteRegion(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteRegion provides completion for region names

func CompleteRegionEnhanced added in v0.11.0

func CompleteRegionEnhanced(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteRegionEnhanced provides enhanced completion for region names with identity, slug, and tab formatting

func CompleteSecurityGroupID

func CompleteSecurityGroupID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteSecurityGroupID provides completion for security group IDs

func CompleteSnapshotID added in v0.8.0

func CompleteSnapshotID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

func CompleteSubnetEnhanced added in v0.11.0

func CompleteSubnetEnhanced(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteSubnetEnhanced provides enhanced completion for subnet IDs with identity, slug, and tab formatting

func CompleteSubnetID

func CompleteSubnetID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteSubnetID provides completion for subnet IDs

func CompleteTfsInstanceID added in v0.12.0

func CompleteTfsInstanceID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

func CompleteVPCID

func CompleteVPCID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteVPCID provides completion for VPC IDs

func CompleteVolumeID added in v0.8.0

func CompleteVolumeID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

func CompleteVpcPeeringConnectionID added in v0.11.0

func CompleteVpcPeeringConnectionID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteVpcPeeringConnectionID provides completion for VPC peering connection identities, names, and slugs

Types

This section is empty.

Jump to