completion

package
v0.14.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 25, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CompleteDbClusterID added in v0.12.0

func CompleteDbClusterID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

func CompleteDbEngineVersion added in v0.14.0

func CompleteDbEngineVersion(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteDbEngineVersion provides completion for DBaaS engine versions It requires the --engine flag to be set to determine which engine versions to return

func CompleteDbInstanceType added in v0.14.0

func CompleteDbInstanceType(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteDbInstanceType provides completion for DBaaS instance types

func CompleteKubernetesCluster added in v0.11.0

func CompleteKubernetesCluster(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteKubernetesCluster provides completion for Kubernetes cluster identities, names, and slugs

func CompleteKubernetesNodePool added in v0.14.0

func CompleteKubernetesNodePool(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteKubernetesNodePool provides completion for Kubernetes node pools It requires the --cluster flag to be set to determine which node pools to return

func CompleteKubernetesVersion added in v0.11.0

func CompleteKubernetesVersion(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteKubernetesVersion provides completion for Kubernetes versions

func CompleteMachineID

func CompleteMachineID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteMachineID provides completion for machine IDs

func CompleteMachineType added in v0.11.0

func CompleteMachineType(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteMachineType provides completion for machine types with descriptions

func CompleteNatGatewayID

func CompleteNatGatewayID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteNatGatewayID provides completion for NAT gateway IDs

func CompleteOrganisation added in v0.13.0

func CompleteOrganisation(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteOrganisation provides completion for organisation identities and slugs

func CompleteOutputFormat

func CompleteOutputFormat(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteOutputFormat provides completion for output format options

func CompleteRegion

func CompleteRegion(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteRegion provides completion for region names

func CompleteRegionEnhanced added in v0.11.0

func CompleteRegionEnhanced(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteRegionEnhanced provides enhanced completion for region names with identity, slug, and tab formatting

func CompleteSecurityGroupID

func CompleteSecurityGroupID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteSecurityGroupID provides completion for security group IDs

func CompleteSnapshotID added in v0.8.0

func CompleteSnapshotID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

func CompleteSubnetEnhanced added in v0.11.0

func CompleteSubnetEnhanced(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteSubnetEnhanced provides enhanced completion for subnet IDs with identity, slug, and tab formatting

func CompleteSubnetID

func CompleteSubnetID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteSubnetID provides completion for subnet IDs

func CompleteTfsInstanceID added in v0.12.0

func CompleteTfsInstanceID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

func CompleteVPCID

func CompleteVPCID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteVPCID provides completion for VPC IDs

func CompleteVolumeID added in v0.8.0

func CompleteVolumeID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

func CompleteVpcPeeringConnectionID added in v0.11.0

func CompleteVpcPeeringConnectionID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteVpcPeeringConnectionID provides completion for VPC peering connection identities, names, and slugs

Types

This section is empty.

Jump to