completion

package
v0.11.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 10, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CompleteKubernetesCluster added in v0.11.0

func CompleteKubernetesCluster(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteKubernetesCluster provides completion for Kubernetes cluster identities, names, and slugs

func CompleteKubernetesVersion added in v0.11.0

func CompleteKubernetesVersion(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteKubernetesVersion provides completion for Kubernetes versions

func CompleteMachineID

func CompleteMachineID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteMachineID provides completion for machine IDs

func CompleteMachineType added in v0.11.0

func CompleteMachineType(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteMachineType provides completion for machine types with descriptions

func CompleteNatGatewayID

func CompleteNatGatewayID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteNatGatewayID provides completion for NAT gateway IDs

func CompleteOutputFormat

func CompleteOutputFormat(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteOutputFormat provides completion for output format options

func CompleteRegion

func CompleteRegion(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteRegion provides completion for region names

func CompleteRegionEnhanced added in v0.11.0

func CompleteRegionEnhanced(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteRegionEnhanced provides enhanced completion for region names with identity, slug, and tab formatting

func CompleteSecurityGroupID

func CompleteSecurityGroupID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteSecurityGroupID provides completion for security group IDs

func CompleteSnapshotID added in v0.8.0

func CompleteSnapshotID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

func CompleteSubnetEnhanced added in v0.11.0

func CompleteSubnetEnhanced(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteSubnetEnhanced provides enhanced completion for subnet IDs with identity, slug, and tab formatting

func CompleteSubnetID

func CompleteSubnetID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteSubnetID provides completion for subnet IDs

func CompleteVPCID

func CompleteVPCID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteVPCID provides completion for VPC IDs

func CompleteVolumeID added in v0.8.0

func CompleteVolumeID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

func CompleteVpcPeeringConnectionID added in v0.11.0

func CompleteVpcPeeringConnectionID(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective)

CompleteVpcPeeringConnectionID provides completion for VPC peering connection identities, names, and slugs

Types

This section is empty.

Jump to