Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InteractiveChoice ¶
InteractiveChoice runs fzf with the given command and returns the selected item. It uses default options for fzf configuration.
func InteractiveChoiceWithOptions ¶
func InteractiveChoiceWithOptions(command string, opts InteractiveChoiceOptions) (string, error)
InteractiveChoiceWithOptions runs fzf with the given command and options, returning the selected item.
func IsInteractiveMode ¶
IsInteractiveMode determines if we can use fzf for interactive selection. It checks if: 1. TC_IGNORE_FZF environment variable is not set 2. stdout is a terminal 3. fzf is installed
Types ¶
type InteractiveChoiceOptions ¶
type InteractiveChoiceOptions struct {
// FzfArgs are additional arguments to pass to the fzf command
FzfArgs []string
// EnablePreview determines if previews should be enabled
EnablePreview bool
}
InteractiveChoiceOptions provides configuration for the interactive choice functionality.
func DefaultOptions ¶
func DefaultOptions() InteractiveChoiceOptions
DefaultOptions returns the default options for interactive choice
Click to show internal directories.
Click to hide internal directories.